@@ -1,28 +1,14 @@
-/*=============================================================================
-
-    This file is part of FLINT.
-
-    FLINT is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    FLINT is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with FLINT; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2010 Sebastian Pancratz
     Copyright (C) 2011 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of FLINT.
+
+    FLINT is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
+*/
 
 #include <gmp.h>
 #include "flint.h"
@@ -38,12 +24,12 @@ _fmpq_poly_evaluate_fmpq(fmpz_t rnum, fmpz_t rden,
 {
     fmpz_t d;
     
-    _fmpz_poly_evaluate_horner_mpq(rnum, rden, poly, len, anum, aden);
+    _fmpz_poly_evaluate_fmpq(rnum, rden, poly, len, anum, aden);
     fmpz_mul(rden, rden, den);
     
     fmpz_init(d);
     fmpz_gcd(d, rnum, rden);
-    if (*d != WORD(1))
+    if (!fmpz_is_one(d))
     {
         fmpz_divexact(rnum, rnum, d);
         fmpz_divexact(rden, rden, d);
